@@ -25,15 +25,11 @@ def metrics(func, X, y, kind, formatstr="{:,.2f}"):
 
 def largest_errors(func, X, y, n=25):
     """Return observations with largest errors in predictions"""
-    pred = func(X)
-    if isinstance(pred, pd.Series):
-        pred = pred.to_numpy()
+    pred = func(X).to_numpy()
 
     df = (
         X.copy()
-        .assign(
-            y=y, pred=pred
-        )  # to numpy is needed to help time inference
+        .assign(y=y, pred=pred)  # to numpy is needed to help time inference
         .astype({"y": float, "pred": float})  # account for boolean output/predictions
         .assign(Delta=lambda x: np.abs(x["y"] - x["pred"]))
     )
@@ -52,10 +48,7 @@ def largest_errors(func, X, y, n=25):
 
 def calibration(func, X, y, bins=10):
     """Plot calibration"""
-    preds = func(X)
-    if isinstance(preds, pd.Series):
-        preds = preds.to_numpy()
-
+    preds = func(X).to_numpy()
     pred_grp = pd.qcut(preds, q=bins, duplicates="drop")
 
     df = pd.DataFrame(
