@@ -43,7 +43,7 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
     pred = endpoint.profile_func(x)
     baseline, explanation = explainer.explain(x)
     example = {
-        "inputs": df_to_dict(x),
+        "inputs": endpoint.input_schema.pydantic.schema()["example"],
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
@@ -111,10 +111,12 @@ def create_expectations(endpoint):
         try:
             chart = condexp(func, x, y, var)
             chart.save(fpath, format="json")
-            print(fpath)
-            print(chart)
         except AttributeError as e:
             logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
+        except TypeError as e:
+            # happens when object columns cannot be serialized to JSON
+            # https://github.com/altair-viz/altair/issues/1355
+            logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
 
 def create_importance(endpoint):
